function classifyResult = challenge(recordName)
%
% Sample entry for the 2017 PhysioNet/CinC Challenge.
%
% INPUTS:
% recordName: string specifying the record name to process
%
% OUTPUTS:
% classifyResult: integer value where
%                     N = normal rhythm
%                     A = AF
%                     O = other rhythm
%                     ~ = noisy recording (poor signal quality)
%
% To run your entry on the entire training set in a format that is
% compatible with PhysioNet's scoring enviroment, run the script
% generateValidationSet.m
%
% The challenge function requires that you have downloaded the challenge
% data 'training_set' in a subdirectory of the current directory.
%    http://physionet.org/physiobank/database/challenge/2017/
%
% This dataset is used by the generateValidationSet.m script to create
% the annotations on your training set that will be used to verify that
% your entry works properly in the PhysioNet testing environment.
%
%
% Version 1.0
%
%
% Written by: Chengyu Liu and Qiao Li January 20 2017
%             chengyu.liu@emory.edu  qiao.li@emory.edu
%
% Last modified by:
%
%
% global total2
% total= total2;
% global template1
% template = template1 ;
% global train_set1
% train_set = train_set1 ;

load total_score
load train_set
load train_set_template
load template
% load template2beats_corrcoef_peak_norm
nstrain = 400;
Train_template = cat(2,template(:,train_set_template(:,1)),template(:,train_set_template(:,2)),template(:,train_set_template(:,3)),template(:,train_set_template(:,4)));
window = 40;
overlap = 20;
cnessAda1 = zeros(1,4);
cnessAda2 = zeros(1,4);
%%

% compute qrs_detect
[tm,ecg,fs,siginfo]=rdmat(recordName);
[QRS] = qrs_detect(ecg');

% compute the scores
[ecg_score,qrs_pos2] = compute_score(ecg,QRS);
ecg_score = real(ecg_score);
[ ecg_score(15) ] = bpm( QRS,fs );
% compute the template
[rf2,Pf, ecg_template]=Create_tpltes(ecg,QRS,diff(QRS),0.2,300);
 ecg_template  = Norma_tplte( ecg_template );
%compute cnessAdaCORR
template_spectrotrain = spectro(Train_template ,window,overlap);
if sum(abs(ecg_template))~=0
[class_tmp,cnessAda1] =clst_elt_CORR( ecg_template,Train_template,nstrain );     
template_spectrotest= spectro(ecg_template,window,overlap);
[class_tmp, cnessAda2] = clst_elt_class_spc( template_spectrotest(:,:,1), template_spectrotrain ,nstrain, 1:4 );
end

ecg_score(16:19) = cnessAda1;
ecg_score(20:23) = cnessAda2;

% use the training set

total1=total_score;
%template set initialisation

% XTemplates = template;
Nlearn = 100;
% window = 40;
% overlap = 20;
nset = 40;
nstrain = 100;
YTrain = []; % labels for training
YTrain(1:nstrain,1) = 1;
YTrain(nstrain+1:2*nstrain,1) = 2;
YTrain(2*nstrain+1:3*nstrain,1) = 3;
YTrain(3*nstrain+1:4*nstrain,1) = 4;
class_ecg = zeros(nset,1);

for p = 1:nset
%% some initialisations first

%% template mean and closest element set initialisation

TrainN = train_set(p,1:nstrain);
TrainA = train_set(p,nstrain+1:2*nstrain);
TrainO = train_set(p,2*nstrain+1:3*nstrain);
Trainnoisy = train_set(p,3*nstrain+1:4*nstrain);
% training set initialisation
% XTrainCEnoisy = cat(2,XTemplates(:,TrainN),XTemplates(:,TrainA),XTemplates(:,TrainO),XTemplates(:,Trainnoisy));
% 
% XTrainCEA = cat(2,XTemplates(:,TrainN),XTemplates(:,TrainA),XTemplates(:,TrainO));
% 
% XTrainCE = cat(2,XTemplates(:,TrainN),XTemplates(:,TrainO));


%% Adaboost sets initialisation

XTrainnoisy = [total1(TrainN,:) ;total1(TrainA,:); total1(TrainO,:) ;total1(Trainnoisy,:)];
XTrainA = [total1(TrainN,:) ;total1(TrainA,:); total1(TrainO,:) ];
XTrain = [total1(TrainN,:); total1(TrainO,:) ];

%% Let's first get rid of the noisy ones

% labels for the first branch : get rid of noisy 
YGROnoisy = 5*(YTrain<4)+4*(YTrain==4);
% labels for the first branch : get rid of Atrial
YGROA = 5*(YTrain(1:3*nstrain)~=2)+ 2*(YTrain(1:3*nstrain)==2); % it's not that important 
%though
%% Training and Testing with Adaboost 

% Training

if exist('ClassTreeEnsnoisy','var') == 0 
    ClassTreeEnsnoisy = fitensemble(XTrainnoisy,YGROnoisy,'AdaboostM1',Nlearn,'Tree');
end

[class_tmp] = predict(ClassTreeEnsnoisy,ecg_score);
if class_tmp == 4
   class_ecg(p) = class_tmp; 
end
%% classifying the Atrial ECGs second
%  Test loop closest ECGs templates spectrogram method

if class_ecg(p) == 0
    if exist('ClassTreeEnsA','var') == 0 
        ClassTreeEnsA = fitensemble(XTrainA,YGROA,'AdaboostM1',Nlearn,'Tree');
    end
    [class_tmp] = predict(ClassTreeEnsA,ecg_score);
    if class_tmp == 2
        class_ecg(p) = class_tmp; 
    end
%     
%     XTestSPCA = spectro(ecg_template,window,overlap);
%     XTrainSPCA = spectro(XTrainCEA,window,overlap);
% 
%     class_tmp = clst_elt_class_spc( XTestSPCA(:,:,1), XTrainSPCA,nstrain, 1:3 );
%     if class_tmp == 2
%         class_ecg(p) = class_tmp; 
%     end
end

%%  Classifying the rest
if class_ecg(p) == 0
    
    if exist('ClassTreeEnsO','var') == 0 
        ClassTreeEnsO = fitensemble(XTrain,[YTrain(1:nstrain); YTrain(2*nstrain+1:3*nstrain)],'AdaboostM1',Nlearn,'Tree');
    end
    class_ecg(p)  = predict(ClassTreeEnsO,ecg_score);
end


end

% class
class_final = mode(class_ecg);

switch class_final
    case 1
        classifyResult = 'N';
    case 2
        classifyResult = 'A';
    case 3
        classifyResult = 'O';
    case 4
        classifyResult = '~';
    otherwise
        keyboard
end

end



