function [ score, ecg , qrs_pos ] = compute_score( ecg1, qrs_pos )
%compute_score :  Compute the score for the adaboost classifier
%   The score are organised this way :
% 1. testqualityQ  2. bsqi_matlab (not working yet) 3. ToneEtropy(Tone)  4. ToneEntropy(Entropy)
% 5. timedomainHRV(meanrr) 6. timedomainHRV(sdrr) 7.timedomainHRV(rmssd)
% 8. Poincarep(w) 9. Poincarep(l) 10. Poincarep(ratio) 11. spechrv(nhf) 
% 12. spechrv(hf) 13. spechrv(tp) 14. karhuloev



score  =  zeros(1,14);
fs = 300;
ecg = ecg1;

if length(qrs_pos)>4 % to be prepared to have noisy ecg with no qrs
        % change qrs_pos to make it contain only usuable beats

        [ecg, qrs_pos ] = adapt_ecg( ecg1, qrs_pos );
        %sometimes detection is a little approximative, these lines are to redress
        %it
        %checking the signs of QRS detected
         count_pos = sum(ecg(qrs_pos)>0);
         count_neg = sum(ecg(qrs_pos)<0);
         
         if count_pos > count_neg && count_neg > 1
            for j = 1 : length(qrs_pos)
                if (qrs_pos(j)+10) < length(ecg) && (qrs_pos(j)-10) > 1
                    [a , b] = max(ecg((qrs_pos(j)-10):(qrs_pos(j)+10))); 
                    b = b-11;
                    qrs_pos(j) = qrs_pos(j) + b;
                end
            end
         elseif count_neg > count_pos && count_pos > 1
             for j = 1 : length(qrs_pos)
                if (qrs_pos(j)+10) < length(ecg) && (qrs_pos(j)-10) > 1
                    [a , b] = min(ecg((qrs_pos(j)-10):(qrs_pos(j)+10))); 
                    b = b-11;
                    qrs_pos(j) = qrs_pos(j) + b;
                end
             end
        end
        
        if length(qrs_pos)<4
            return
        end
            
        RR = diff(qrs_pos); % R-R intervals

        % testqualityQ
        af = 0.4;
        [rf2,score(1),Tf] = testqualityQ(ecg,qrs_pos,af); 
        
        %bsqi
        if length(ecg1)> 10*fs
            
            Thold = 0.1;
            try 
                [score(2)] = bsqi_matlab( ecg,qrs_pos,fs, Thold );
            catch err
                score(2) = -1;
            end
        else
            disp('no bsqi for me')
        end

        %tone entropy
        %[Tone, Entropy]
        [score(3),score(4)] = ToneEntropy( RR );

        %timedomainHRV 
        %[meanrr(i),sdrr(i),rmssd(i)] 
        [score(5),score(6),score(7)] = timedomainHRV( RR ); 

        %Poincarep
        %[w(i),l(i),ratio(i)] = Poincarep( RR );
        [score(8),score(9),score(10)] = Poincarep( RR );

        %spechrv
        [nvlf,nlf,nhf,lf,hf,lh,tp]=spechrv(RR,fs,fs); %spechrv
        %nvlf(i); % useless
        %nlf(i); % useless
        score(11) = nhf;
        %lf(i); % useless
        score(12) = hf;
        %lh(i); % useless
        score(13) = tp;
% 
        % for the karhuloev
        coef = karhuloev( ecg,qrs_pos );
        score(14) = coef;
end
end

