function [ qrs_pos] = qrs_detect( ecg )
%qrs_detect: Computes the qrs_pos using qrs_detect2 in a windowed manner.
% window size is 3 seconds. You need miss detect to make this algorithm
% work, it helps to correct miss detection.
% you can force the sign of the qrs detected if you specify sign (1 or -1)
    
    % mean filtering to reduce noise
%     ecg = conv(ecg2,ones(15,1));
%     ecg = ecg(150:end); % often the beginning is corrupted by filter
    fs = 300;
    ref_period = 0.25;
    thres = 0.5;
    window = 3*fs;
    qrs_pos = [];
    for p = 1:window:length(ecg)
         
        if p==1
            f = p;
        else
            if p>length(ecg)
                 p = length(ecg);
                 [qrs_postmp,sign,en_thres] = qrs_detect2(ecg(f:p),thres,ref_period,fs); %R positions
                 qrs_pos = [qrs_pos,qrs_postmp+f];
                 break
            end
            [qrs_postmp,sign,en_thres] = qrs_detect2(ecg(f:p),thres,ref_period,fs); %R positions
            u = 1;
            while length(qrs_pos)>2 && u<length(qrs_postmp) && abs((f+qrs_postmp(u))-qrs_pos(end))<0.25*fs
                u = u+1;
            end
            
            qrs_pos = [qrs_pos,qrs_postmp(u:end)+f];
     
            f = p;
        end
     end
%      if i ==3
%      keyboard
%      end

     %checking bad R detection due to windowing
      Med_Thresh = median(abs(ecg(qrs_pos)));
     tmp = abs(abs(ecg(qrs_pos))-Med_Thresh)>abs(0.5*Med_Thresh) ;
     if sum(tmp)>0
         qrs_pos(tmp)=[];
     end
     
     %checking for beat detection alternating between positive and negative
     %values
     
     if sum(ecg(qrs_pos)>=0)>length(qrs_pos)/10 && sum(ecg(qrs_pos)<=0)> length(qrs_pos)/10
         if sum(ecg(qrs_pos)>=0)>sum(ecg(qrs_pos)<=0)
             signtot = 1;
         else
             signtot = -1;
         end
         %then we do it all over again but only considering positive or
         %negative beats
         qrs_pos = [];
         for p = 1:window:length(ecg)

            if p==1
                f = p;
            else
                if p>length(ecg)
                     p = length(ecg);
                     [qrs_postmp,sign,en_thres] = qrs_detect2(ecg(f:p),thres,ref_period,fs,[],signtot); %R positions
                     qrs_pos = [qrs_pos,qrs_postmp+f];
                     break
                end
                [qrs_postmp,sign,en_thres] = qrs_detect2(ecg(f:p),thres,ref_period,fs,[],signtot); %R positions
                if p<2 && abs((f+qrs_postmp(1))-qrs_pos(end))<0.25*fs 
                    qrs_pos = [qrs_pos,qrs_postmp(2:end)+f];
                else
                    qrs_pos = [qrs_pos,qrs_postmp(1:end)+f];
                end
                f = p;
            end             
         end
         Med_Thresh = median(abs(ecg(qrs_pos)));
         tmp = abs(abs(ecg(qrs_pos))-Med_Thresh)>abs(0.5*Med_Thresh) ;
    end
     