function [ spec_template ] = spectro( template, wsize, overlap, wtype )
%SPECTRO compute the spectrograms of the templates in input
%   Input: template -> template you want the spectrogram to be computed
% multiple templates can be given as multiple columns
%          wsize -> window size for the Fourier Transform (default door window)
%          overlap -> overlapping between windows
%          wtype -> type of window used (default door) type:char           
%   Output: spec_template -> output spectrogram in 2D, if multiple
%   templates then 3rd dimension represent different templates
% to imporve the algorithm we can implement several windows (raised cosine
% etc...)

% if no widow is specified
if nargin ==3 
    [rows,columns] =  size(template);

    if columns>1
        for Ns = 1:columns
            for step = 1:round(rows/(wsize-overlap))
                if (step-1)*(wsize-overlap)+wsize > rows
                    break
                end
                spec_template(:,step,Ns) = fftshift(abs(fft(template((step-1)*(wsize-overlap)+1 :...
                    (step-1)*(wsize-overlap)+wsize,Ns))));
            end
        end

    else
        for step = 1:round(rows/(wsize-overlap))
            if (step-1)*(wsize-overlap)+wsize > rows
                break
            end
            spec_template(:,step) = fftshift(abs(fft(template((step-1)*(wsize-overlap)+1 :...
                (step-1)*(wsize-overlap)+wsize,1))));
        end
    end
    
% if a window is specified
elseif nargin ==4
   switch wtype
       case 'blackman'
           window = blackman(wsize);
       case 'hamming'
           window = hamming(wsize);
       case 'hann'
           window = hann(wsize);
       case 'chebwin'
           window = chebwin(wsize);
       case 'gausswin'
           window = gausswin(wsize);
       case 'kaiser'
           window = kaiser(wsize,5);
       case 'flattopwin'
           window = flattopwin(wsize);
       otherwise 
           disp('please enter a window among: blackman hamming or hann')
   end
           
   [rows,columns] =  size(template);
   if columns>1
        for Ns = 1:columns
            for step = 1:round(rows/(wsize-overlap))
                if (step-1)*(wsize-overlap)+wsize > rows
                    break
                end
                spec_template(:,step,Ns) = fftshift(abs(fft(template((step-1)*(wsize-overlap)+1 :...
                    (step-1)*(wsize-overlap)+wsize,Ns).*window)));
            end
        end

    else
        for step = 1:round(rows/(wsize-overlap))
            if (step-1)*(wsize-overlap)+wsize > rows
                break
            end
            spec_template(:,step) = fftshift(abs(fft(template((step-1)*(wsize-overlap)+1 :...
                (step-1)*(wsize-overlap)+wsize,1).*window)));
        end
    end
    
else 
    disp('please enter 3 or 4 arguments :) ')
end
    

end



